emacs-elpa-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[elpa] externals/ebdb c11ef0e 334/350: Rename ebdb-message-header to ebd


From: Eric Abrahamsen
Subject: [elpa] externals/ebdb c11ef0e 334/350: Rename ebdb-message-header to ebdb-mua-message-header
Date: Mon, 14 Aug 2017 11:47:05 -0400 (EDT)

branch: externals/ebdb
commit c11ef0eb78fc10d054b9f5131209ac752199402d
Author: Eric Abrahamsen <address@hidden>
Commit: Eric Abrahamsen <address@hidden>

    Rename ebdb-message-header to ebdb-mua-message-header
    
    Best to get some naming consistency now, before anyone really uses
    this.
---
 ebdb-gnus.el    |  6 +++---
 ebdb-message.el |  6 +++---
 ebdb-mhe.el     |  6 +++---
 ebdb-mu4e.el    |  2 +-
 ebdb-mua.el     |  8 ++++----
 ebdb-pgp.el     |  2 +-
 ebdb-rmail.el   |  4 ++--
 ebdb-vm.el      |  8 ++++----
 ebdb.info       | 16 ++++++++--------
 ebdb.org        |  6 +++---
 ebdb.texi       |  6 +++---
 11 files changed, 35 insertions(+), 35 deletions(-)

diff --git a/ebdb-gnus.el b/ebdb-gnus.el
index 4d0e318..fea53c6 100644
--- a/ebdb-gnus.el
+++ b/ebdb-gnus.el
@@ -433,19 +433,19 @@ Note that `\( is the backquote, NOT the quote '\(."
 ;; absence of some headers.
 ;; See http://permalink.gmane.org/gmane.emacs.gnus.general/78741
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode gnus-summary-mode))
   "Return value of HEADER for current Gnus message."
   (set-buffer gnus-article-buffer)
   (gnus-fetch-original-field header))
 
 ;; This is all a little goofy.
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode gnus-article-mode))
   (set-buffer gnus-article-buffer)
   (gnus-fetch-original-field header))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode gnus-tree-mode))
   (set-buffer gnus-article-buffer)
   (gnus-fetch-original-field header))
diff --git a/ebdb-message.el b/ebdb-message.el
index f0573d5..c7210f7 100644
--- a/ebdb-message.el
+++ b/ebdb-message.el
@@ -50,15 +50,15 @@
   "Produce a EBDB buffer name associated with Mail mode."
   (ebdb-message-buffer-name))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                    &context (major-mode message-mode))
   (message-field-value header))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                    &context (major-mode notmuch-message-mode))
   (message-field-value header))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                    &context (major-mode mail-mode))
   (message-field-value header))
 
diff --git a/ebdb-mhe.el b/ebdb-mhe.el
index 2d7e2bc..74464a4 100644
--- a/ebdb-mhe.el
+++ b/ebdb-mhe.el
@@ -62,15 +62,15 @@ Returns the empty string if HEADER is not in the message."
   "Produce a EBDB buffer name associated with mh-hmode."
   (format "*%s-MHE*" ebdb-buffer-name))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode mhe-mode))
   (ebdb/mh-header header))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode mhe-summary-mode))
   (ebdb/mh-header header))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode mhe-folder-mode))
   (ebdb/mh-header header))
 
diff --git a/ebdb-mu4e.el b/ebdb-mu4e.el
index f2fcf75..2e4ee5e 100644
--- a/ebdb-mu4e.el
+++ b/ebdb-mu4e.el
@@ -29,7 +29,7 @@
 
 ;; Tackle `mu4e-headers-mode' later
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode mu4e-view-mode))
   (set-buffer mu4e~view-buffer-name)
   (message-field-value header))
diff --git a/ebdb-pgp.el b/ebdb-pgp.el
index 7cdeac5..e3eefae 100644
--- a/ebdb-pgp.el
+++ b/ebdb-pgp.el
@@ -184,7 +184,7 @@ use one of the following, as appropriate:
                                   (ebdb-extract-address-components
                                    (mapconcat
                                     (lambda (header)
-                                      (ebdb-message-header header))
+                                      (ebdb-mua-message-header header))
                                     ebdb-pgp-headers ", ")
                                    t)))))))
                  (and ebdb-pgp-default-action
diff --git a/ebdb-rmail.el b/ebdb-rmail.el
index dfa1672..604f93e 100644
--- a/ebdb-rmail.el
+++ b/ebdb-rmail.el
@@ -43,11 +43,11 @@
         (mail-header (intern-soft (downcase header))
                      (mail-header-extract))))))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode rmail-mode))
   (ebdb/rmail-header header))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode rmail-summary-mode))
   (ebdb/rmail-header header))
 
diff --git a/ebdb-vm.el b/ebdb-vm.el
index 88f911e..27f5f4c 100644
--- a/ebdb-vm.el
+++ b/ebdb-vm.el
@@ -305,19 +305,19 @@ from different senders."
   "Produce a EBDB buffer name associated with VM mode."
   (format "*%s-VM*" ebdb-buffer-name))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode vm-mode))
   (ebdb/vm-header header))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode vm-virtual-mode))
   (ebdb/vm-header header))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode vm-summary-mode))
   (ebdb/vm-header header))
 
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode vm-presentation-mode))
   (ebdb/vm-header header))
 
diff --git a/ebdb.info b/ebdb.info
index 79eb290..6082813 100644
--- a/ebdb.info
+++ b/ebdb.info
@@ -1631,8 +1631,8 @@ the nationality or locality of the field instance.
 
    • Name fields are keyed to the symbol representing the script used to
      write them.  Specifically, the first character CHAR of the name is
-     tested in this way: (aref char-script-table CHAR), which returns a
-     symbol.
+     tested in this way: ‘(aref char-script-table CHAR)’, which returns
+     a symbol.
 
    How are these “specs” used?  Each internationalized version of the
 above methods accepts the spec as an additional argument, which it is
@@ -1712,11 +1712,11 @@ examples.
    When ‘ebdb-mua-auto-update’ runs, it scans the headers of the current
 article/message for name/mail data, and uses that data to locate,
 create, edit, and display records.  It does this by calling the generic
-function ‘ebdb-message-header’ with the string header name; it is the
-responsibility of the MUA to implement this function, and return the
+function ‘ebdb-mua-message-header’ with the string header name; it is
+the responsibility of the MUA to implement this function, and return the
 contents of the appropriate header.  For instance, in Gnus:
 
-     (cl-defmethod ebdb-message-header ((header string)
+     (cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode gnus-summary-mode))
        "Return value of HEADER for current Gnus message."
        (set-buffer gnus-article-buffer)
@@ -1941,9 +1941,9 @@ Node: Actions52495
 Node: Custom Field Searching53160
 Node: Formatting in the EBDB Buffer54948
 Node: Writing Internationalization Libraries56947
-Node: Writing Integration For New MUAs61292
-Node: Article snarfing64710
-Node: Index65432
+Node: Writing Integration For New MUAs61298
+Node: Article snarfing64724
+Node: Index65446
 
 End Tag Table
 
diff --git a/ebdb.org b/ebdb.org
index e6d7fb9..ca54831 100644
--- a/ebdb.org
+++ b/ebdb.org
@@ -1260,7 +1260,7 @@ nationality or locality of the field instance.
   ~ebdb-i18n-phone-codes~.
 - Name fields are keyed to the symbol representing the script used to
   write them. Specifically, the first character CHAR of the name is
-  tested in this way: =(aref char-script-table CHAR)=, which returns a
+  tested in this way: ~(aref char-script-table CHAR)~, which returns a
   symbol.
 
 How are these "specs" used?  Each internationalized version of the
@@ -1339,12 +1339,12 @@ for examples.
 When ~ebdb-mua-auto-update~ runs, it scans the headers of the current
 article/message for name/mail data, and uses that data to locate,
 create, edit, and display records.  It does this by calling the
-generic function ~ebdb-message-header~ with the string header name; it
+generic function ~ebdb-mua-message-header~ with the string header name; it
 is the responsibility of the MUA to implement this function, and
 return the contents of the appropriate header.  For instance, in Gnus:
 
 #+BEGIN_SRC emacs-lisp
-  (cl-defmethod ebdb-message-header ((header string)
+  (cl-defmethod ebdb-mua-message-header ((header string)
                                      &context (major-mode gnus-summary-mode))
     "Return value of HEADER for current Gnus message."
     (set-buffer gnus-article-buffer)
diff --git a/ebdb.texi b/ebdb.texi
index 3affac7..fe7da2d 100644
--- a/ebdb.texi
+++ b/ebdb.texi
@@ -1746,7 +1746,7 @@ spec.  These codes can be found in the variable
 @item
 Name fields are keyed to the symbol representing the script used to
 write them. Specifically, the first character CHAR of the name is
-tested in this way: @verb{~(aref char-script-table CHAR)~}, which returns a
+tested in this way: @code{(aref char-script-table CHAR)}, which returns a
 symbol.
 @end itemize
 
@@ -1829,12 +1829,12 @@ for examples.
 When @code{ebdb-mua-auto-update} runs, it scans the headers of the current
 article/message for name/mail data, and uses that data to locate,
 create, edit, and display records.  It does this by calling the
-generic function @code{ebdb-message-header} with the string header name; it
+generic function @code{ebdb-mua-message-header} with the string header name; it
 is the responsibility of the MUA to implement this function, and
 return the contents of the appropriate header.  For instance, in Gnus:
 
 @lisp
-(cl-defmethod ebdb-message-header ((header string)
+(cl-defmethod ebdb-mua-message-header ((header string)
                                   &context (major-mode gnus-summary-mode))
   "Return value of HEADER for current Gnus message."
   (set-buffer gnus-article-buffer)



reply via email to

[Prev in Thread] Current Thread [Next in Thread]
diff --git a/ebdb-mua.el b/ebdb-mua.el
index 776a6f8..ac5eeb6 100644
--- a/ebdb-mua.el
+++ b/ebdb-mua.el
@@ -483,7 +483,7 @@ Currently no other MUAs support this EBDB feature."
 
 (defsubst ebdb-message-header-re (header regexp)
   "Return non-nil if REGEXP matches value of HEADER."
-  (let ((val (ebdb-message-header header))
+  (let ((val (ebdb-mua-message-header header))
         (case-fold-search t)) ; RW: Is this what we want?
     (and val (string-match regexp val))))
 
@@ -536,7 +536,7 @@ variables `ebdb-user-mail-address-re',
                     (ebdb-mua-check-header header-type address-parts t)))))))
 
 ;; How are you supposed to do the &context arglist for a defgeneric?
-(cl-defgeneric ebdb-message-header (header)
+(cl-defgeneric ebdb-mua-message-header (header)
   "Get value of HEADER for the mua keyed to major-mode.")
 
 (defun ebdb-get-address-components (&optional header-class ignore-address)
@@ -559,7 +559,7 @@ are discarded as appropriate."
     (condition-case nil
        (dolist (headers message-headers)
          (dolist (header (cdr headers))
-           (when (setq content (ebdb-message-header header))
+           (when (setq content (ebdb-mua-message-header header))
              (setq content (mail-decode-encoded-word-string content))
              (dolist (address (ebdb-extract-address-components content t))
                (setq mail (cadr address))
@@ -575,7 +575,7 @@ are discarded as appropriate."
                  (push mail mail-list)
                  (push (list (car address) (cadr address) header (car headers) 
major-mode) address-list))))))
       (cl-no-applicable-method
        ;; Potentially triggered by `ebdb-message-header', which
        ;; dispatches on major-mode.
        (error "EBDB does not support %s" major-mode)))
     (or (nreverse address-list)
@@ -575,7 +575,7 @@ are discarded as appropriate."
major-mode) address-list))))))
       (cl-no-applicable-method
-       ;; Potentially triggered by `ebdb-message-header', which
+       ;; Potentially triggered by `ebdb-mua-message-header', which
        ;; dispatches on major-mode.
        (error "EBDB does not support %s" major-mode)))